@@ -29,8 +29,10 @@
 #define W_PACKAGE_URL PBU_WIDEN(PACKAGE_URL)
 #endif // ]
 #define FPRINTF(stream,format) fwprintf(stream,L##format)
+#define FVPRINTF(stream,format,...) fwprintf(stream,L##format,__VA_ARGS__)
 #else // ] [
 #define FPRINTF(stream,format) fprintf(stream,format)
+#define FVPRINTF(stream,format,...) fprintf(stream,format,__VA_ARGS__)
 #endif // ]
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -56,51 +58,39 @@
   (0==((o)->aggregate&BS1770GAIN_AGGREGATE_RANGE_PEAK))
 
 ///////////////////////////////////////////////////////////////////////////////
-#if defined (_WIN32) // [
-void bs1770gain_usage(wchar_t **wargv, char **argv, int code)
-#else // ] [
+#define BS177GAIN_NANOS_GIGANTUM_HUMERIS_INSIDENTES \
+    "Nanos gigantum humeris insidentes. #TeamWhite"
 void bs1770gain_usage(char **argv, int code)
-#endif // ]
 {
-#if defined (_WIN32) // [
-#if defined (W_PACKAGE_VERSION) // [
-  fwprintf(stderr,L"BS1770GAIN %s, Copyright (C) Peter Belkner 2014-2017.\n",
-      W_PACKAGE_VERSION);
-#endif // ]
-#if defined (W_PACKAGE_URL) // [
-  fwprintf(stderr,L"%s\n",W_PACKAGE_URL);
-#endif // ]
-  fwprintf(stderr,L"\n");
-  fwprintf(stderr,L"Usage:  %s [options] <file/dir> [<file/dir> ...]\n",
-      pbu_wbasename(wargv[0]));
-  fwprintf(stderr,L"\n");
-#else // ] [
+	FILE *f=code?stderr:stdout;
 #if defined (PACKAGE_VERSION) // [
-  fprintf(stderr,"BS1770GAIN %s, Copyright (C) Peter Belkner 2014-2017.\n",
+  fprintf(f,"BS1770GAIN %s, Copyright (C) Peter Belkner 2014-2018.\n",
       PACKAGE_VERSION);
 #endif // ]
+#if defined (BS177GAIN_NANOS_GIGANTUM_HUMERIS_INSIDENTES) // [
+  fputs(BS177GAIN_NANOS_GIGANTUM_HUMERIS_INSIDENTES "\n",f);
+#endif // ]
 #if defined (PACKAGE_URL) // [
-  fprintf(stderr,"%s\n",PACKAGE_URL);
+  fprintf(f,"%s\n",PACKAGE_URL);
 #endif // ]
-  fprintf(stderr,"\n");
-  fprintf(stderr,"Usage:  %s [options] <file/dir> [<file/dir> ...]\n",
+  fprintf(f,"\n");
+  fprintf(f,"Usage:  %s [options] <file/dir> [<file/dir> ...]\n",
       pbu_basename(argv[0]));
-  fprintf(stderr,"\n");
-#endif // ]
-  FPRINTF(stderr,"Options:\n");
-  FPRINTF(stderr," -h,--help:  print this message and exit\n");
+  fprintf(f,"\n");
+  FPRINTF(f,"Options:\n");
+  FPRINTF(f," -h,--help:  print this message and exit\n");
   /////////////////////////////////////////////////////////////////////////////
-  FPRINTF(stderr," -i,--integrated:  calculate integrated loudness\n");
-  FPRINTF(stderr," -s,--shorterm:  calculate maximum shortterm loudness\n");
-  FPRINTF(stderr," -m,--momentary:  claculate maximum momentary loudness\n");
-  FPRINTF(stderr," -r,--range:  calculate loudness range\n");
-  FPRINTF(stderr," -p,--samplepeak:  calculate maximum sample peak\n");
-  FPRINTF(stderr," -t,--truepeak:  calculate maximum true peak\n");
-  FPRINTF(stderr," -b <timestamp>,--begin <timestamp>:  begin decoding at\n"
+  FPRINTF(f," -i,--integrated:  calculate integrated loudness\n");
+  FPRINTF(f," -s,--shorterm:  calculate maximum shortterm loudness\n");
+  FPRINTF(f," -m,--momentary:  calculate maximum momentary loudness\n");
+  FPRINTF(f," -r,--range:  calculate loudness range\n");
+  FPRINTF(f," -p,--samplepeak:  calculate maximum sample peak\n");
+  FPRINTF(f," -t,--truepeak:  calculate maximum true peak\n");
+  FPRINTF(f," -b <timestamp>,--begin=<timestamp>:  begin decoding at\n"
       "   timestamp (in microseconds, format: hh:mm:ss.mus)\n");
-  FPRINTF(stderr," -d <duration>,--duration <duration>:  let decoding\n"
+  FPRINTF(f," -d <duration>,--duration=<duration>:  let decoding\n"
       "   last duration (in microseconds, format: hh:mm:ss.mus)\n");
-  FPRINTF(stderr," -u <method>,--use <method>:  base replay gain calculation\n"
+  FPRINTF(f," -u <method>,--use=<method>:  base replay gain calculation\n"
       "   on method (with respect to the -a/--apply and -o/--output\n"
       "   options),\n"
       "   methods:  \"integrated\" (default), \"shortterm\", or\n"
@@ -109,13 +99,13 @@ void bs1770gain_usage(char **argv, int code)
       "   \"integrated\"), \"momentary-maximum\" (same as \"momentary\"),\n"
       "   \"shortterm-mean\", or \"shortterm-maximum\" (same as\n"
       "   \"shortterm\")\n");
-  FPRINTF(stderr," -a:  apply the EBU/ATSC/RG album gain to the output\n"
+  FPRINTF(f," -a:  apply the EBU/ATSC/RG album gain to the output\n"
       "   (in conjunction with the -o/--output option)\n");
-  FPRINTF(stderr," -o <folder>,--output <folder>:  write RG tags\n"
+  FPRINTF(f," -o <folder>,--output=<folder>:  write RG tags\n"
       "   or apply the EBU/ATSC/RG gain, respectively,\n"
       "   and output to folder\n");
-  FPRINTF(stderr," -f <file>,--file <file>:  write analysis to file\n");
-  FPRINTF(stderr," -x,--extensions:  enable following extensions/defaults:\n"
+  FPRINTF(f," -f <file>,--file=<file>:  write analysis to file\n");
+  FPRINTF(f," -x,--extensions:  enable following extensions/defaults:\n"
       "   1) rename files according to TITLE tag\n"
       "   2) read metadata from per-folder CSV file \"folder.csv\"\n"
       "   3) copy file \"folder.jpg\" from source to destination\n"
@@ -124,103 +114,113 @@ void bs1770gain_usage(char **argv, int code)
       "   5) calculate maximum true peak\n"
       "   6) convert to stereo\n");
 #if defined (_WIN32) && defined (W_OPTION_UTF16) // [
-  FPRINTF(stderr," -v,--utf-16:  use utf-16 for classical (i.e. non-xml)\n"
+  FPRINTF(f," -v,--utf-16:  use utf-16 for classical (i.e. non-xml)\n"
       "   output (may be useful for languages containing non-ascii symbols,\n"
       "   currently supresses displaying progress of analysis)\n");
 #endif // ]
-  FPRINTF(stderr," -l,--list:  print FFmpeg format/stream information\n");
+  FPRINTF(f," -l,--list:  print FFmpeg format/stream information\n");
   /////////////////////////////////////////////////////////////////////////////
-  FPRINTF(stderr," --ebu:  calculate replay gain according to EBU R128\n"
+  FPRINTF(f," --ebu:  calculate replay gain according to EBU R128\n"
       "   (-23.0 LUFS, default)\n");
-  FPRINTF(stderr," --atsc:  calculate replay gain according to ATSC A/85\n"
+  FPRINTF(f," --atsc:  calculate replay gain according to ATSC A/85\n"
       "   (-24.0 LUFS)\n");
-  FPRINTF(stderr," --replaygain:  calculate replay gain according to\n"
+  FPRINTF(f," --replaygain:  calculate replay gain according to\n"
       "   ReplayGain 2.0 (-18.0 LUFS)\n");
-  FPRINTF(stderr," --track-tags:  write track tags\n");
-  FPRINTF(stderr," --album-tags:  write album tags\n");
+  FPRINTF(f," --track-tags:  write track tags\n");
+  FPRINTF(f," --album-tags:  write album tags\n");
 #if defined (BS1770GAIN_TAG_PREFIX) // [
 #if 0 // [
-  FPRINTF(stderr," --tag-prefix <prefix>:  use <prefix> as tag prefix\n"
+  FPRINTF(f," --tag-prefix=<prefix>:  use <prefix> as tag prefix\n"
       "   instead of \"REPLAYGAIN\"\n");
 #else // ] [
-  FPRINTF(stderr," --tag-prefix <prefix>:  instead of \"REPLAYGAIN\",\n"
+  FPRINTF(f," --tag-prefix=<prefix>:  instead of \"REPLAYGAIN\",\n"
       "   use <prefix> as RG tag prefix\n");
 #endif // ]
 #endif // ]
-  FPRINTF(stderr," --unit <unit>:  write tags with <unit>\n");
-  FPRINTF(stderr," --apply <q>:  apply the EBU/ATSC/RG gain to the output\n"
+  FPRINTF(f," --unit=<unit>:  write tags with <unit>\n");
+  FPRINTF(f," --apply=<q>:  apply the EBU/ATSC/RG gain to the output\n"
       "   (in conjunction with the -o/--output option),\n"
       "   q=0.0 (album gain) ... 1.0 (track gain),\n"
       "   default:  0.0 (album gain)\n");
-  FPRINTF(stderr," --audio <index>:  select audio index (corresponds to\n"
+  FPRINTF(f," --audio=<index>:  select audio index (corresponds to\n"
       "   [0:<index>] in FFmpeg listing, cf. -l/--list option)\n");
-  FPRINTF(stderr," --video <index>:  select video index (corresponds to\n"
+  FPRINTF(f," --video=<index>:  select video index (corresponds to\n"
       "   [0:<index>] in FFmpeg listing, cf. -l/--list option)\n");
-  FPRINTF(stderr," --stereo:  convert to stereo\n");
-  FPRINTF(stderr," --drc <float>:  set AC3 dynamic range compression (DRC)\n");
-  FPRINTF(stderr," --extension <extension>:  enable extension out of\n"
+  FPRINTF(f," --stereo:  convert to stereo\n");
+  FPRINTF(f," --drc=<float>:  set AC3 dynamic range compression (DRC)\n");
+  FPRINTF(f," --extension=<extension>:  enable extension out of\n"
       "   \"rename\":  rename files according to TITLE tag\n"
       "   \"csv\":  read metadata from per-folder CSV file \"folder.csv\"\n"
       "   \"jpg\":  copy file \"folder.jpg\" from source to destination\n"
       "      folder\n"
       "   \"tags\":  automatically add the TRACK and DISC tags\n");
-  FPRINTF(stderr," --format <format>:  convert to format\n");
-  FPRINTF(stderr," --loglevel <level>:  set loglevel,\n"
+  FPRINTF(f," --format=<format>:  convert to format\n");
+  FPRINTF(f," --loglevel=<level>:  set loglevel,\n"
       "   level:  \"quiet\", \"panic\", \"fatal\", \"error\", \"warning\",\n"
       "   \"info\", \"verbose\", \"debug\"\n");
-  FPRINTF(stderr," --xml:  print results in xml format\n");
-  FPRINTF(stderr," --time:  print out duration of program invocation\n");
-  FPRINTF(stderr," --norm <float>:  norm loudness to float.\n");
-  //FPRINTF(stderr," --preamp <preamp>:\n");
-  //FPRINTF(stderr," --stero:\n");
-  //FPRINTF(stderr," --rg-tags:\n");
-  //FPRINTF(stderr," --bwf-tags:\n");
+  FPRINTF(f," --xml:  print results in xml format\n");
+  FPRINTF(f," --time:  print out duration of program invocation\n");
+  FPRINTF(f," --norm=<float>:  norm loudness to float.\n");
+  //FPRINTF(f," --preamp=<preamp>:\n");
+  //FPRINTF(f," --stero:\n");
+  //FPRINTF(f," --rg-tags:\n");
+  //FPRINTF(f," --bwf-tags:\n");
+#if defined (BS1770GAIN_OVERWRITE) // [
+  FPRINTF(f," --overwrite:  replace any input files by their respective\n"
+      "   output files (this option takes precedence over -o/--output). An\n"
+      "   input file is not really replaced but moved to a file with a name\n"
+      "   constructed from the old name by \"<old name>.BS1770GAIN\".\n");
+#endif // ]
+#if defined (FFSOX_LFE_CHANNEL) // [
+  FVPRINTF(f," --lfe=<lfe channel> overwrite the default lfe channel"
+      " (default: %d).\n",FFSOX_LFE_CHANNEL);
+#endif // ]
   /////////////////////////////////////////////////////////////////////////////
-  FPRINTF(stderr,"\n");
-  FPRINTF(stderr,"Experimental options:\n");
+  FPRINTF(f,"\n");
+  FPRINTF(f,"Experimental options:\n");
   ////////
-  FPRINTF(stderr,"1) momentary block\n");
-  FPRINTF(stderr," --momentary-mean:  calculate mean loudness based on\n"
+  FPRINTF(f,"1) momentary block\n");
+  FPRINTF(f," --momentary-mean:  calculate mean loudness based on\n"
       "   momentary block (same as --integrated)\n");
-  FPRINTF(stderr," --momentary-maximum:  calculate maximum loudness based\n"
+  FPRINTF(f," --momentary-maximum:  calculate maximum loudness based\n"
       "   on momentary block (same as --momentary)\n");
-  FPRINTF(stderr," --momentary-range:  calculate loudness range based on\n"
+  FPRINTF(f," --momentary-range:  calculate loudness range based on\n"
       "   momentary block\n");
-  FPRINTF(stderr," --momentary-length <ms>:  length of momentary block\n"
+  FPRINTF(f," --momentary-length=<ms>:  length of momentary block\n"
       "   in milliseconds (default: 400)\n");
-  FPRINTF(stderr," --momentary-overlap <percent>:  overlap of momentary\n"
+  FPRINTF(f," --momentary-overlap=<percent>:  overlap of momentary\n"
       "   block in percent (default: 75)\n");
-  FPRINTF(stderr," --momentary-mean-gate <gate>:  silence gate for mean\n"
+  FPRINTF(f," --momentary-mean-gate=<gate>:  silence gate for mean\n"
       "   measurement of momentary block (default: -10.0)\n");
-  FPRINTF(stderr," --momentary-range-gate <gate>:  silence gate for range\n"
+  FPRINTF(f," --momentary-range-gate=<gate>:  silence gate for range\n"
       "   measurement of momentary block (default: -20.0)\n");
-  FPRINTF(stderr," --momentary-range-lower-bound <float>:  lower bound for\n"
+  FPRINTF(f," --momentary-range-lower-bound=<float>:  lower bound for\n"
       "   range measurement of momentary block (default: 0.1)\n");
-  FPRINTF(stderr," --momentary-range-upper-bound <float>:  upper bound for\n"
+  FPRINTF(f," --momentary-range-upper-bound=<float>:  upper bound for\n"
       "   range measurement of momentary block (default: 0.95)\n");
   ////////
-  FPRINTF(stderr,"2) shortterm block\n");
-  FPRINTF(stderr," --shortterm-mean:  calculate mean loudness based on\n"
+  FPRINTF(f,"2) shortterm block\n");
+  FPRINTF(f," --shortterm-mean:  calculate mean loudness based on\n"
       "   shortterm block\n");
-  FPRINTF(stderr," --shortterm-maximum:  calculate maximum loudness based\n"
+  FPRINTF(f," --shortterm-maximum:  calculate maximum loudness based\n"
       "   on shortterm block (same as --shortterm)\n");
-  FPRINTF(stderr," --shortterm-range:  calculate loudness range based on\n"
+  FPRINTF(f," --shortterm-range:  calculate loudness range based on\n"
       "   shortterm block (same as --range)\n");
-  FPRINTF(stderr," --shortterm-length <ms>:  length of shortterm block\n"
+  FPRINTF(f," --shortterm-length=<ms>:  length of shortterm block\n"
       "   in milliseconds (default: 3000)\n");
-  FPRINTF(stderr," --shortterm-overlap <percent>:  overlap of shortterm\n"
+  FPRINTF(f," --shortterm-overlap <percent>:  overlap of shortterm\n"
       "   block in percent (default: 67)\n");
-  FPRINTF(stderr," --shortterm-mean-gate <gate>:  silence gate for mean\n"
+  FPRINTF(f," --shortterm-mean-gate=<gate>:  silence gate for mean\n"
       "   measurement of shortterm block (default: -10.0)\n");
-  FPRINTF(stderr," --shortterm-range-gate <gate>:  silence gate for range\n"
+  FPRINTF(f," --shortterm-range-gate=<gate>:  silence gate for range\n"
       "   measurement of shortterm block (default: -20.0)\n");
-  FPRINTF(stderr," --shortterm-range-lower-bound <float>:  lower bound for\n"
+  FPRINTF(f," --shortterm-range-lower-bound=<float>:  lower bound for\n"
       "   range measurement of shortterm block (default: 0.1)\n");
-  FPRINTF(stderr," --shortterm-range-upper-bound <float>:  upper bound for\n"
+  FPRINTF(f," --shortterm-range-upper-bound=<float>:  upper bound for\n"
       "   range measurement of shortterm block (default: 0.95)\n");
   /////////////////////////////////////////////////////////////////////////////
-  FPRINTF(stderr,"\n");
-  FPRINTF(stderr,"Command line arguments can appear in any order.\n");
+  FPRINTF(f,"\n");
+  FPRINTF(f,"Command line arguments can appear in any order.\n");
 #if defined (_WIN32) // [
   free(argv);
 #endif // ]
@@ -251,9 +251,15 @@ enum {
   TRACK_TAGS,
   ALBUM_TAGS,
   XML,
-#if defined (BS1770GAIN_TAG_PREFIX) // {
+#if defined (BS1770GAIN_TAG_PREFIX) // [
   TAG_PREFIX,
-#endif // }
+#endif // ]
+#if defined (BS1770GAIN_OVERWRITE) // [
+  OVERWRITE,
+#endif // ]
+#if defined (FFSOX_LFE_CHANNEL) // [
+  LFE_CHANNEL,
+#endif // ]
   ////////////////
   MOMENTARY_RANGE,
   MOMENTARY_LENGTH,
@@ -319,9 +325,15 @@ static struct option bs1770gain_opts[]={
   { "track-tags",no_argument,NULL,TRACK_TAGS },
   { "album-tags",no_argument,NULL,ALBUM_TAGS },
   { "xml",no_argument,NULL,XML },
-#if defined (BS1770GAIN_TAG_PREFIX) // {
+#if defined (BS1770GAIN_TAG_PREFIX) // [
   { "tag-prefix",required_argument,NULL,TAG_PREFIX },
-#endif // }
+#endif // ]
+#if defined (BS1770GAIN_OVERWRITE) // [
+  { "overwrite",no_argument,NULL,OVERWRITE },
+#endif // ]
+#if defined (FFSOX_LFE_CHANNEL) // [
+  { "lfe",required_argument,NULL,LFE_CHANNEL },
+#endif // ]
   ////
   { "momentary-mean",no_argument,NULL,'i' },
   { "momentary-maximum",no_argument,NULL,'m' },
@@ -361,6 +373,11 @@ static struct option bs1770gain_opts[]={
 };
 
 ///////////////////////////////////////////////////////////////////////////////
+#if 0 // [
+#define BS1770GAIN_ERROR -1
+#else // ] [
+#define BS1770GAIN_ERROR 1
+#endif // ]
 #if defined (_WIN32) // {
 static char **bs1770gain_wargv2argv(int argc, wchar_t **wargv)
 {
@@ -422,6 +439,9 @@ int main(int argc, char **argv)
 #if defined (_WIN32) // {
   char **argv;
 #endif // }
+#if defined (BS1770GAIN_VERSIONS) // [
+  sox_version_info_t const *sox_version;
+#endif // ]
   options_t options;
   FILE *f=stdout;
   tree_t root;
@@ -510,13 +530,13 @@ fprintf(stderr,"\n");
 #endif // ]
 #endif // ]
 
-  if (1==argc) {
-#if defined (_WIN32) // [
-    bs1770gain_usage(wargv,argv,-1);
+#if 1 // [
+  if (1==argc)
+    bs1770gain_usage(argv,BS1770GAIN_ERROR);
 #else // ] [
-    bs1770gain_usage(argv,-1);
+  if (1==argc)
+    bs1770gain_usage(argv,0);
 #endif // ]
-  }
 
   TRACE_PUSH();
 
@@ -528,12 +548,15 @@ fprintf(stderr,"\n");
   options.norm=-23.0;
   options.audio_ext="flac";
   options.video_ext="mkv";
-#if defined (BS1770GAIN_TAG_PREFIX) // {
+#if defined (BS1770GAIN_TAG_PREFIX) // [
   options.tag_prefix="REPLAYGAIN";
-#endif // }
+#endif // ]
 #if defined (_WIN32) // [
   options.utf16=0;
 #endif // ]
+#if defined (FFSOX_LFE_CHANNEL) // [
+  options.lfe=FFSOX_LFE_CHANNEL;
+#endif // ]
 
   options.momentary.ms=400.0;
   options.momentary.partition=4;
@@ -557,11 +580,7 @@ fprintf(stderr,"\n");
     case '?':
       fprintf(stderr,"Error: Option \"%s\" not recognizsed.\n",argv[optind-1]);
       fprintf(stderr,"\n");
-#if defined (_WIN32) // [
-      bs1770gain_usage(wargv,argv,-1);
-#else // ] [
-      bs1770gain_usage(argv,-1);
-#endif // ]
+      bs1770gain_usage(argv,BS1770GAIN_ERROR);
       break;
     /// with argument /////////////////////////////////////////////////////////
     case 'b':
@@ -599,11 +618,7 @@ fprintf(stderr,"\n");
       else {
         fprintf(stderr,"Error: Method \"%s\" not recognized.\n",optarg);
         fprintf(stderr,"\n");
-#if defined (_WIN32) // [
-        bs1770gain_usage(wargv,argv,-1);
-#else // ] [
-        bs1770gain_usage(argv,-1);
-#endif // ]
+        bs1770gain_usage(argv,BS1770GAIN_ERROR);
       }
 
       break;
@@ -613,11 +628,7 @@ fprintf(stderr,"\n");
       options.apply=0.0;
       break;
     case 'h':
-#if defined (_WIN32) // [
-      bs1770gain_usage(wargv,argv,0);
-#else // ] [
       bs1770gain_usage(argv,0);
-#endif // ]
       break;
     case 'l':
       options.dump=1;
@@ -676,22 +687,28 @@ fprintf(stderr,"\n");
         options.extensions|=EXTENSION_JPG;
       else if (0==strcasecmp("tags",optarg))
         options.extensions|=EXTENSION_TAGS;
-      else {
-#if defined (_WIN32) // [
-        bs1770gain_usage(wargv,argv,-1);
-#else // ] [
-        bs1770gain_usage(argv,-1);
-#endif // ]
-      }
+      else
+        bs1770gain_usage(argv,BS1770GAIN_ERROR);
+
       break;
-#if defined (BS1770GAIN_TAG_PREFIX) // {
+#if defined (BS1770GAIN_TAG_PREFIX) // [
     case TAG_PREFIX:
       options.tag_prefix=optarg;
       break;
-#endif // }
+#endif // ]
     case FORMAT:
       options.format=optarg;
       break;
+#if defined (BS1770GAIN_OVERWRITE) // [
+    case OVERWRITE:
+      options.overwrite=1;
+      break;
+#endif // ]
+#if defined (FFSOX_LFE_CHANNEL) // [
+    case LFE_CHANNEL:
+      options.lfe=atoi(optarg);
+      break;
+#endif // ]
     case LOGLEVEL:
       if (0==strcasecmp("quiet",optarg))
         loglevel=AV_LOG_QUIET;
@@ -709,13 +726,9 @@ fprintf(stderr,"\n");
         loglevel=AV_LOG_VERBOSE;
       else if (0==strcasecmp("debug",optarg))
         loglevel=AV_LOG_DEBUG;
-      else {
-#if defined (_WIN32) // [
-        bs1770gain_usage(wargv,argv,-1);
-#else // ] [
-        bs1770gain_usage(argv,-1);
-#endif // ]
-      }
+      else
+        bs1770gain_usage(argv,BS1770GAIN_ERROR);
+
       break;
     case NORM:
       options.norm=atof(optarg);
@@ -771,11 +784,7 @@ fprintf(stderr,"\n");
       else {
         FPRINTF(stderr,"Error: Overlap out of range [0..100).\n");
         FPRINTF(stderr,"\n");
-#if defined (_WIN32) // [
-        bs1770gain_usage(wargv,argv,-1);
-#else // ] [
-        bs1770gain_usage(argv,-1);
-#endif // ]
+        bs1770gain_usage(argv,BS1770GAIN_ERROR);
       }
 
       break;
@@ -807,11 +816,7 @@ fprintf(stderr,"\n");
       else {
         FPRINTF(stderr,"Error: Overlap out of range [0..100).\n");
         FPRINTF(stderr,"\n");
-#if defined (_WIN32) // [
-        bs1770gain_usage(wargv,argv,-1);
-#else // ] [
-        bs1770gain_usage(argv,-1);
-#endif // ]
+        bs1770gain_usage(argv,BS1770GAIN_ERROR);
       }
 
       break;
@@ -836,11 +841,7 @@ fprintf(stderr,"\n");
   if (0!=options.method&&NULL==odirname) {
     FPRINTF(stderr,"Error: \"-u/--use\" requieres \"-o/--output\".\n");
     FPRINTF(stderr,"\n");
-#if defined (_WIN32) // [
-    bs1770gain_usage(wargv,argv,-1);
-#else // ] [
-    bs1770gain_usage(argv,-1);
-#endif // ]
+    bs1770gain_usage(argv,BS1770GAIN_ERROR);
   }
 
   if (BS1770GAIN_IS_MODE_APPLY(options.mode)&&NULL!=options.format) {
@@ -849,13 +850,8 @@ fprintf(stderr,"\n");
     options.format=NULL;
   }
 
-  if (options.momentary.partition<1||options.shortterm.partition<1) {
-#if defined (_WIN32) // [
-    bs1770gain_usage(wargv,argv,-1);
-#else // ] [
-    bs1770gain_usage(argv,-1);
-#endif // ]
-  }
+  if (options.momentary.partition<1||options.shortterm.partition<1)
+    bs1770gain_usage(argv,BS1770GAIN_ERROR);
 
   if (options.momentary.range_lower_bound<=0.0
       ||options.momentary.range_upper_bound
@@ -868,11 +864,7 @@ fprintf(stderr,"\n");
     FPRINTF(stderr,"Error: Range bounds out of range "
         " 0.0 < lower < upper < 1.0.\n");
     FPRINTF(stderr,"\n");
-#if defined (_WIN32) // [
-    bs1770gain_usage(wargv,argv,-1);
-#else // ] [
-    bs1770gain_usage(argv,-1);
-#endif // ]
+    bs1770gain_usage(argv,BS1770GAIN_ERROR);
   }
 
   if (!BS1770GAIN_IS_MODE_APPLY(options.mode)) {
@@ -890,19 +882,57 @@ fprintf(stderr,"\n");
 
 #if defined (_WIN32) // [
 #if defined (W_OPTION_UTF16) // [
-  options.utf16&=!options.xml;
+  if (!options.xml)
+    options.utf16=1;
 #else // ] [
   options.utf16=!options.xml;
 #endif // ]
 #endif // ]
 
+#if defined (HAVE_FFSOX_DYNLOAD) // [
   // load the FFmpeg and SoX libraries from "bs1770gain-tools".
   if (ffsox_dynload("bs1770gain-tools")<0) {
     PBU_DMESSAGE("loading shared libraries");
     goto dynload;
   }
+#endif // ]
 
+#if defined (BS1770GAIN_VERSIONS) // [
+  if (LIBAVUTIL_VERSION_MAJOR!=AV_VERSION_MAJOR(avutil_version())) {
+    DVMESSAGE("wrong version of avutil: %d needed.",
+        LIBAVUTIL_VERSION_MAJOR);
+    goto versions;
+  }
+
+  if (LIBSWRESAMPLE_VERSION_MAJOR!=AV_VERSION_MAJOR(swresample_version())) {
+    DVMESSAGE("wrong version of swresample: %d needed.",
+        LIBSWRESAMPLE_VERSION_MAJOR);
+    goto versions;
+  }
+
+  if (LIBAVCODEC_VERSION_MAJOR!=AV_VERSION_MAJOR(avcodec_version())) {
+    DVMESSAGE("wrong version of avcodec: %d needed.",
+        LIBAVCODEC_VERSION_MAJOR);
+    goto versions;
+  }
+
+  if (LIBAVFORMAT_VERSION_MAJOR!=AV_VERSION_MAJOR(avformat_version())) {
+    DVMESSAGE("wrong version of avformat: %d needed.",
+        LIBAVFORMAT_VERSION_MAJOR);
+    goto versions;
+  }
+
+  sox_version=sox_version_info();
+
+  if (!sox_version||SOX_LIB_VERSION_CODE!=sox_version->version_code) {
+    DVMESSAGE("wrong version of libsox: %d needed.",SOX_LIB_VERSION_CODE);
+    goto versions;
+  }
+#endif // ]
+
+#if LIBAVFORMAT_VERSION_MAJOR < 58 // [
   av_register_all();
+#endif // ]
   sox_init();
 
   if (0==options.dump||av_log_get_level()<loglevel)
@@ -982,7 +1012,6 @@ fprintf(stderr,"\n");
   sox_quit();
   // still reachable: 9,689 bytes in 51 blocks
   // TODO: Cleanup FFmpeg. But how?
-dynload:
 #if defined (_WIN32) // [
   if (NULL!=wfpath)
     fclose(f);
@@ -996,12 +1025,18 @@ file:
     FREE(wfpath);
 wfpath:
 #endif // ]
+#if defined (BS1770GAIN_VERSIONS) // [
+versions:
+#endif // ]
+#if defined (HAVE_FFSOX_DYNLOAD) // [
+  ffsox_unload();
+dynload:
+#endif // ]
 #if defined (_WIN32) // {
   FREE(argv);
 argv:
 #endif // }
   TRACE_POP();
   PBU_HEAP_PRINT();
-
   return 0;
 }
