@@ -59,7 +59,8 @@ int ffsox_sink_open(sink_t *s)
 {
 #if ! defined (FFSOX_NO_AVFMT_NOFILE) // [
   if (0==(s->f.fc->oformat->flags&AVFMT_NOFILE)) {
-    if (avio_open(&s->f.fc->pb,s->f.path,AVIO_FLAG_WRITE)<0) {
+DWRITELN(s->f.path);
+    if (avio_open(&s->f.fc->pb,s->f.path,AVIO_FLAG_READ_WRITE)<0) {
       DMESSAGE("opening output file");
       goto open;
     }
